@@ -640,6 +640,8 @@ class Connector:
         --------
         options: List[str]
             required when input_type is 'select' - a list with the selection-options
+            options can be a numpy array too (or any other object implementing `tolist() -> List[List[]]`)
+
         unicast_to : int
             the device number to which this message is sent exclusively.
 
@@ -659,6 +661,7 @@ class Connector:
             what should the user be prompted for?
         options: List[str]
             a list with the options a user can select
+            options can be a numpy array too (or any other object implementing `tolist() -> List[List[]]`)
 
         Optional
         --------
@@ -687,6 +690,8 @@ class Connector:
         --------
         options: List[str]
             required when input_type is 'select' - a list with the selection-options
+            options can be a numpy array too (or any other object implementing `tolist() -> List[List[]]`)
+
         unicast_to : int
             the device number to which this message is sent exclusively.
 
@@ -698,6 +703,9 @@ class Connector:
         '''
         ts = self.current_time_stamp
 
+        if callable(getattr(options, 'tolist', None)):
+            options = options.tolist()
+
         if input_type == 'datetime':
             input_type = 'datetime-local'
 
@@ -951,12 +959,60 @@ class Connector:
             device_id=self.__last_sent_grid.device_id
         )
 
+    def set_image(self, image: List[str], device_id: str = None, unicast_to: int = None, broadcast: bool = False, base_color: Optional[Tuple[int, int, int]] = None):
+        '''
+        Parameters
+        ----------
+        image : List<str> a list containing strings build up with spaces or values between 0 and 9. When other characters
+                    are used, 9 (full color) is used instead
+
+        Optional
+        --------
+        base_color : Tuple[r, g, b] representing the base rgb color 0-255
+
+        device_id : str control the device with this id
+
+        unicast_to : int control the device with the given number
+
+        broadcast : bool wheter to send this message to all connected devices
+
+
+        Example
+        -------
+        write HELLO
+        ```py
+        image = [
+            '9  9 9999 9     9     99999',
+            '9  9 9    9     9     9   9',
+            '9999 9999 9     9     9   9',
+            '9  9 9    9     9     9   9',
+            '9  9 9999 99999 99999 99999'
+        ]
+        phone.set_image(image)
+        ```
+        '''
+        grid = []
+        for char_row in image:
+            row = []
+            for char in char_row:
+                try:
+                    row.append(int(char))
+                except ValueError:
+                    if char == ' ':
+                        row.append(0)
+                    else:
+                        row.append(9)
+            grid.append(row)
+        return self.set_grid(grid, device_id=device_id, unicast_to=unicast_to, broadcast=broadcast, base_color=base_color)
+
     def set_grid(self, grid: Union[List[Union[str, int, Tuple[R, G, B], Tuple[R, G, B, HUE]]], List[List[Union[str, int, Tuple[R, G, B], Tuple[R, G, B, HUE]]]]], device_id: str = None, unicast_to: int = None, broadcast: bool = False, base_color: Optional[Tuple[int, int, int]] = None):
         '''
         Parameters
         ----------
         grid : List<List<str>> a 2d array containing the color of each cell, an rgb, rgba tuple or an integer between 0 and 9
-                representing the brightness of the base color 
+                representing the brightness of the base color
+
+                grid can be a numpy array too (or any other object implementing `tolist() -> List[List[]]`)
 
         Optional
         --------
@@ -978,6 +1034,9 @@ class Connector:
         ])
         ```
         '''
+        if callable(getattr(grid, 'tolist', None)):
+            grid = grid.tolist()
+
         raw_grid = grid
         is_2d = len(grid) > 0 and type(grid[0]) != str and hasattr(grid[0], "__getitem__")
         if is_2d:
@@ -1323,22 +1382,34 @@ class Connector:
 
 if __name__ == '__main__':
     logging.basicConfig(level=logging.DEBUG)
-    # phone = Connector('http://localhost:5000', 'FooBar')
-    phone = Connector('https://io.lebalz.ch', 'FooBar')
+    phone = Connector('http://localhost:5000', 'FooBar')
+    # phone = Connector('https://io.lebalz.ch', 'FooBar')
+    response = phone.input("Hallo")
+
+    image = [
+        '9  9 9999 9     9     99999',
+        '9  9 9    9     9     9   9',
+        '9999 9999 9     9     9   9',
+        '9  9 9    9     9     9   9',
+        '9  9 9999 99999 99999 99999'
+    ]
+
+    phone.set_image(image, base_color=(255, 255, 0))
+    phone.sleep(5)
     phone.set_grid(
-        [[0]]
+        [[0]], base_color=(255, 255, 0)
     )
     grid = []
-    for i in range(100):
+    for i in range(10):
         row = []
-        for j in range(100):
-            row.append((j + i) // 20)
+        for j in range(10):
+            row.append((j + i) // 2)
         grid.append(row)
-    phone.set_grid(grid)
-    phone.sleep()
-    phone.set_grid_at(5, 5, 'red')
+    phone.set_grid(grid, base_color=(255, 255, 0))
+    phone.sleep(3)
+    phone.set_grid_at(5, 5, 7)
     phone.sleep(1)
-    phone.set_grid_at(2, 5, 'red')
+    phone.set_grid_at(2, 5, 3)
     t0 = time_s()
 
     # Screen().tracer(0, 0)
